using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ComService;
using System.IO.Ports;
using System.Threading;
using DBService;

namespace ComServiceTry
{
    class Program
    {        
        static void Main(string[] args)
        {
            DBService.DBService dbservice = new DBService.DBService();
            /*int count = dbservice.Count("test");
            List<string>[] list = new List<string>[2];
            list[0] = new List<string>();
            list[1] = new List<string>();

            dbservice.Select("SELECT * FROM test", ref list);*/
            //dbservice.CreateTable();
            //dbservice.Insert();

            List<string>[] list = new List<string>[6];
            list[0] = new List<string>();
            list[1] = new List<string>();
            list[2] = new List<string>();
            list[3] = new List<string>();
            list[4] = new List<string>();
            list[5] = new List<string>();


            //dbservice.Select("SELECT * FROM iot_devices", ref list);
            //dbservice.Select("SELECT * FROM AspNetUserLogins", ref list);

            int count = dbservice.Count("Users");
            Console.ReadLine();
        }

        /*static void Main(string[] args)
        {
            //StmService port = new StmService("COM5", 115200, Parity.None, 8, StopBits.One);
            StmService port = new StmService();
            port.Connect();
            int tmp = port.Temperature;
            int hum = port.Humidity;
            Thread.Sleep(1000);
            int tmp1 = port.Temperature;
            int hum1 = port.Humidity;
            Console.ReadLine();
        }*/
    }
}
